(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16789,        379]*)
(*NotebookOutlinePosition[     17433,        401]*)
(*  CellTagsIndexPosition[     17389,        397]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Display notebook for the data produced by plasmaball.c", "Subsubtitle"],

Cell["\<\
Use must set path to the location of the files produced by C-code\
\>", "Text"],

Cell[BoxData[
    \(SetDirectory["\<???\>"]\)], "Input"],

Cell["\<\
Must set p to the value of DIM in the C-code. (This equals 'd' in the \
paper)\
\>", "Text"],

Cell[BoxData[
    \(p = 3\)], "Input"],

Cell["Import the various data files", "Text"],

Cell[BoxData[{
    \(\(\(X = Import["\<saveX\>", "\<Table\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Y = Import["\<saveY\>", "\<Table\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(h = Import["\<saveh\>", "\<Table\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(f = Import["\<savef\>", "\<Table\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(fmag = 
        Import["\<savefmag\>", "\<Table\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(A = Import["\<saveA\>", "\<Table\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(B = Import["\<saveB\>", "\<Table\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(CC = Import["\<saveC\>", "\<Table\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(DD = Import["\<saveD\>", "\<Table\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(T = Import["\<saveT\>", "\<Table\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(U = Import["\<saveU\>", "\<Table\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(R = Import["\<saveR\>", "\<Table\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(S = Import["\<saveS\>", "\<Table\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(temp = Import["\<savetemp\>", "\<Table\>"];\)\)}], "Input"],

Cell["Find x,y ranges and sizes of arrays", "Text"],

Cell[BoxData[{
    \(\(\(xmin = Min[X];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(xmax = Max[X];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(ymin = Min[Y];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(ymax = Max[Y];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(xsize = Length[X]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(ysize = Length[X[\([1]\)]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(xarr = X[\([Range[1, xsize], 1]\)];\)\)}], "Input"],

Cell["\<\
Compute asymptotic leading order coefficients - see paper (Appendix F) for \
asymptotic behaviour\
\>", "Text"],

Cell[BoxData[{
    \(\(asymT = \(1\/f^\((p + 1)\)\) \((T - 
              1)\);\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(asymU = \(1\/f^\((p + 1)\)\) \((U - 
              1)\);\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(asymS = \(1\/f^\((p + 1)\)\) 
          S;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(asymR = \(1\/f^\((p + 1)\)\) R;\)\)}], "Input"],

Cell["Neaten data arrays up ", "Text"],

Cell[BoxData[{
    \(Adisp = A; Bdisp = B; Cdisp = CC; 
    Ddisp = DD;\), "\[IndentingNewLine]", 
    \(Tdisp = T; Udisp = U; Sdisp = S; Rdisp = R;\), "\[IndentingNewLine]", 
    \(Tttdisp = \(-\((\((p + 1)\) asymT + asymR)\)\); 
    Taadisp = \(-\((\((p + 1)\) asymU + asymR)\)\); 
    Trrdisp = \(1\/\((p - 
                2)\)\) \((\((p + 1)\) \((asymT + asymU)\) + \((p + 4)\) 
              asymR)\); 
    Tggdisp = \(-\((p + 2)\)\) asymR;\), "\[IndentingNewLine]", 
    \(\(fdisp = f;\)\), "\[IndentingNewLine]", 
    \(\(tempdisp = temp;\)\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]If[
        temp[\([i, j]\)] \[Equal] 0 || 
          temp[\([i, j]\)] \[Equal] 4, \[IndentingNewLine]Adisp[\([i, j]\)] = 
          10; \[IndentingNewLine]Bdisp[\([i, j]\)] = 
          10; \[IndentingNewLine]Cdisp[\([i, j]\)] = 
          10; \[IndentingNewLine]Ddisp[\([i, j]\)] = 
          10; \[IndentingNewLine]Tdisp[\([i, j]\)] = 
          10; \[IndentingNewLine]Udisp[\([i, j]\)] = 
          10; \[IndentingNewLine]Sdisp[\([i, j]\)] = 
          10; \[IndentingNewLine]Rdisp[\([i, j]\)] = 
          10; \[IndentingNewLine]Tttdisp[\([i, j]\)] = 
          NAN; \[IndentingNewLine]Taadisp[\([i, j]\)] = 
          NAN; \[IndentingNewLine]Trrdisp[\([i, j]\)] = 
          NAN; \[IndentingNewLine]Tggdisp[\([i, j]\)] = 
          NAN; \[IndentingNewLine]fdisp[\([i, j]\)] = 
          0;\[IndentingNewLine]]; \[IndentingNewLine]If[
        temp[\([i, j]\)] \[Equal] 2\  || \ 
          temp[\([i, j]\)] \[Equal] 3, \[IndentingNewLine]Adisp[\([i, j]\)] = 
          A[\([i, j]\)]; \[IndentingNewLine]Bdisp[\([i, j]\)] = 
          B[\([i, j]\)]; \[IndentingNewLine]Cdisp[\([i, j]\)] = 
          CC[\([i, j]\)]; \[IndentingNewLine]Ddisp[\([i, j]\)] = 
          DD[\([i, j]\)]; \[IndentingNewLine]Tdisp[\([i, 
              j]\)] = \(-1\); \[IndentingNewLine]Udisp[\([i, 
              j]\)] = \(-1\); \[IndentingNewLine]Sdisp[\([i, 
              j]\)] = \(-1\); \[IndentingNewLine]Rdisp[\([i, 
              j]\)] = \(-1\); \[IndentingNewLine]Tttdisp[\([i, j]\)] = 
          NAN; \[IndentingNewLine]Taadisp[\([i, j]\)] = 
          NAN; \[IndentingNewLine]Trrdisp[\([i, j]\)] = 
          NAN; \[IndentingNewLine]Tggdisp[\([i, j]\)] = 
          NAN; \[IndentingNewLine]fdisp[\([i, j]\)] = 
          NAN;\[IndentingNewLine]]; \[IndentingNewLine]If[
        temp[\([i, j]\)] \[Equal] 
          1, \[IndentingNewLine]Adisp[\([i, j]\)] = \(1\/f[\([i, j]\)]\) 
            T[\([i, j]\)]; \[IndentingNewLine]Bdisp[\([i, 
              j]\)] = \(1\/f[\([i, j]\)]\) 
            U[\([i, j]\)]; \[IndentingNewLine]Cdisp[\([i, 
              j]\)] = \(-Log[f[\([i, j]\)]]\) + 
            S[\([i, j]\)]; \[IndentingNewLine]Ddisp[\([i, 
              j]\)] = \(-Log[f[\([i, j]\)]]\) + Log[fmag[\([i, j]\)]] + 
            R[\([i, j]\)]; \[IndentingNewLine]Tdisp[\([i, j]\)] = 
          T[\([i, j]\)]; \[IndentingNewLine]Udisp[\([i, j]\)] = 
          U[\([i, j]\)]; \[IndentingNewLine]Sdisp[\([i, j]\)] = 
          S[\([i, j]\)]; \[IndentingNewLine]Rdisp[\([i, j]\)] = 
          R[\([i, j]\)]; \[IndentingNewLine]fdisp[\([i, j]\)] = 
          f[\([i, j]\)];\[IndentingNewLine]];\[IndentingNewLine], {i, 1, 
        xsize}, {j, 1, ysize}]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]If[
        j > i, \[IndentingNewLine]Adisp[\([i, j]\)] = 
          Bdisp[\([j, i]\)]; \[IndentingNewLine]Bdisp[\([i, j]\)] = 
          Adisp[\([j, i]\)]; \[IndentingNewLine]Cdisp[\([i, j]\)] = 
          Cdisp[\([j, i]\)]; \[IndentingNewLine]Ddisp[\([i, j]\)] = 
          Ddisp[\([j, i]\)]; \[IndentingNewLine]Tdisp[\([i, j]\)] = 
          Udisp[\([j, i]\)]; \[IndentingNewLine]Udisp[\([i, j]\)] = 
          Tdisp[\([j, i]\)]; \[IndentingNewLine]Sdisp[\([i, j]\)] = 
          Sdisp[\([j, i]\)]; \[IndentingNewLine]Rdisp[\([i, j]\)] = 
          Rdisp[\([j, i]\)]; \[IndentingNewLine]fdisp[\([i, j]\)] = 
          fdisp[\([j, i]\)]; \[IndentingNewLine]Tttdisp[\([i, j]\)] = 
          Taadisp[\([j, i]\)]; \[IndentingNewLine]Taadisp[\([i, j]\)] = 
          Tttdisp[\([j, i]\)]; \[IndentingNewLine]Trrdisp[\([i, j]\)] = 
          Trrdisp[\([j, i]\)]; \[IndentingNewLine]Tggdisp[\([i, j]\)] = 
          Tggdisp[\([j, i]\)]; \[IndentingNewLine]tempdisp[\([i, j]\)] = 
          tempdisp[\([j, i]\)];\[IndentingNewLine]]\[IndentingNewLine], {i, 
        1, xsize}, {j, 1, ysize}]\)}], "Input"],

Cell["Interpolate functions for plotting from the arrays", "Text"],

Cell[BoxData[{
    \(\(\(fdispfn[x_, 
          y_] = \(ListInterpolation[fdisp, {{xmin, xmax}, {ymin, ymax}}, 
            InterpolationOrder \[Rule] 1]\)[x, y];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Afn[x_, 
          y_] = \(ListInterpolation[Adisp, {{xmin, xmax}, {ymin, ymax}}]\)[x, 
          y];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Bfn[x_, 
          y_] = \(ListInterpolation[Bdisp, {{xmin, xmax}, {ymin, ymax}}]\)[x, 
          y];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Cfn[x_, 
          y_] = \(ListInterpolation[Cdisp, {{xmin, xmax}, {ymin, ymax}}]\)[x, 
          y];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Dfn[x_, 
          y_] = \(ListInterpolation[Ddisp, {{xmin, xmax}, {ymin, ymax}}]\)[x, 
          y];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Tttfn[x_, 
          y_] = \(ListInterpolation[Tttdisp, {{xmin, xmax}, {ymin, ymax}}]\)[
          x, y];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Taafn[x_, 
          y_] = \(ListInterpolation[Taadisp, {{xmin, xmax}, {ymin, ymax}}]\)[
          x, y];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Trrfn[x_, 
          y_] = \(ListInterpolation[Trrdisp, {{xmin, xmax}, {ymin, ymax}}]\)[
          x, y];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Tggfn[x_, 
          y_] = \(ListInterpolation[Tggdisp, {{xmin, xmax}, {ymin, ymax}}]\)[
          x, y];\)\)}], "Input"],

Cell[BoxData[
    \(\(view = {\(-1.838\), \ \(-1.845\), \ 2.160};\)\)], "Input"],

Cell[BoxData[{
    \(\(\(Print["\<Plot of 'f' - defined in UV region (h<h0)\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(tmp = 
      Plot3D[\(-fdispfn[x, y]\), {x, 0, xmax}, {y, 0, ymax}, 
        PlotRange \[Rule] {\(-0. \), \(-0.54\)}, ViewPoint \[Rule] view, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<-f  \>"}, 
        BoxRatios \[Rule] {xmax, ymax, 1}, PlotPoints \[Rule] 40, 
        Ticks \[Rule] {{0, 1, 2, 3, 4}, {0, 1}, Automatic}, 
        Mesh -> False]\)}], "Input"],

Cell[BoxData[{
    \(\(\(Print["\<Surface plots of A,B,C,D in x, y plane\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(tmp1 = 
      Plot3D[Afn[x, y], {x, 0, xmax}, {y, 0, ymax}, PlotRange \[Rule] {0, 3}, 
        ViewPoint \[Rule] view, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<A\>"}, 
        BoxRatios \[Rule] {xmax, ymax, 1}, PlotPoints \[Rule] 40, 
        Ticks \[Rule] {{0, 1, 2, 3, 4}, {0, 1}, Automatic}, 
        Mesh -> False]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(tmp2 = 
      Plot3D[Bfn[x, y], {x, 0, xmax}, {y, 0, ymax}, PlotRange \[Rule] {0, 3}, 
        ViewPoint \[Rule] view, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<B\>"}, 
        BoxRatios \[Rule] {xmax, ymax, 1}, PlotPoints \[Rule] 40, 
        Ticks \[Rule] {{0, 1, 2, 3, 4}, {0, 1}, Automatic}, 
        Mesh -> False]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(tmp3 = 
      Plot3D[Exp[Cfn[x, y]], {x, 0, xmax}, {y, 0, ymax}, 
        PlotRange \[Rule] {0, 3}, ViewPoint \[Rule] view, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", \*"\"\<\!\(e\^C\)\>\""}, 
        BoxRatios \[Rule] {xmax, ymax, 1}, PlotPoints \[Rule] 40, 
        Ticks \[Rule] {{0, 1, 2, 3, 4}, {0, 1}, Automatic}, 
        Mesh -> False]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(tmp4 = 
      Plot3D[Exp[Dfn[x, y]], {x, 0, xmax}, {y, 0, ymax}, 
        PlotRange \[Rule] {0, 3}, ViewPoint \[Rule] view, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", \*"\"\<\!\(e\^D\)\>\""}, 
        BoxRatios \[Rule] {xmax, ymax, 1}, PlotPoints \[Rule] 40, 
        Ticks \[Rule] {{0, 1, 2, 3, 4}, {0, 1}, Automatic}, 
        Mesh -> False]\)}], "Input"],

Cell[BoxData[{
    \(\(\(Print["\<Contour plots of A,B,C,D in x, y plane\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(tmp1 = 
      ContourPlot[Afn[x, y], {x, 0, xmax}, {y, 0, ymax}, 
        AspectRatio \[Rule] Automatic, PlotRange \[Rule] {0, 5}, 
        PlotPoints \[Rule] 100]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(tmp2 = 
      ContourPlot[Bfn[x, y], {x, 0, xmax}, {y, 0, ymax}, 
        AspectRatio \[Rule] Automatic, PlotRange \[Rule] {0, 5}, 
        PlotPoints \[Rule] 100]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(tmp3 = 
      ContourPlot[Exp[Cfn[x, y]], {x, 0, xmax}, {y, 0, ymax}, 
        AspectRatio \[Rule] Automatic, PlotRange \[Rule] {0, 5}, 
        PlotPoints \[Rule] 100]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(tmp4 = 
      ContourPlot[Exp[Dfn[x, y]], {x, 0, xmax}, {y, 0, ymax}, 
        AspectRatio \[Rule] Automatic, PlotRange \[Rule] {0, 5}, 
        PlotPoints \[Rule] 100]\)}], "Input"],

Cell["\<\
Compute kappa function which should be constant along IR boundaries, giving \
the proper gradient of the vanishing circle size.

2 \[Pi] / kappa evaluated at the IR boundary gives the coordinate size of the \
circles for regularity of the Euclidean solution\
\>", "Text"],

Cell[BoxData[
    \(\(kappa[x_, y_] = Exp[\(-Dfn[x, y]\)] D[Afn[x, y], y];\)\)], "Input"],

Cell[BoxData[{
    \(\(\(Plot["\<Plot showing \[Kappa] on the IR boundary (normalized by the \
value at `infinity' \n   - should equal one if constraints are satisfied\>"];\
\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(tmp = 
      Plot[kappa[x, 0]\/kappa[xmax, 0], {x, xmin, xmax}, 
        PlotRange \[Rule] {0.95, 1.05}, 
        AxesLabel \[Rule] {"\<x\>", "\<\[Kappa](x)/\[Kappa](\[Infinity])\>"}]\
\)}], "Input"],

Cell["\<\
Show the boundary stress tensor (without field theory vacuum subtraction) \
components near the UV boundary\
\>", "Text"],

Cell[BoxData[{
    \(tmp1 = 
      Plot3D[Tttfn[x, y], {x, 0, xmax}, {y, 0, ymax}, 
        PlotRange \[Rule] {\(-4\), 10}, ViewPoint \[Rule] view, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<A\>"}, 
        BoxRatios \[Rule] {xmax, ymax, 1}, PlotPoints \[Rule] 40, 
        Ticks \[Rule] {{0, 1, 2, 3, 4}, {0, 1}, Automatic}, 
        Mesh -> False]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(tmp2 = 
      Plot3D[Taafn[x, y], {x, 0, xmax}, {y, 0, ymax}, 
        PlotRange \[Rule] {\(-4\), 10}, ViewPoint \[Rule] view, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<B\>"}, 
        BoxRatios \[Rule] {xmax, ymax, 1}, PlotPoints \[Rule] 40, 
        Ticks \[Rule] {{0, 1, 2, 3, 4}, {0, 1}, Automatic}, 
        Mesh -> False]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(tmp3 = 
      Plot3D[Trrfn[x, y], {x, 0, xmax}, {y, 0, ymax}, 
        PlotRange \[Rule] {\(-4\), 10}, ViewPoint \[Rule] view, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", \*"\"\<\!\(e\^C\)\>\""}, 
        BoxRatios \[Rule] {xmax, ymax, 1}, PlotPoints \[Rule] 40, 
        Ticks \[Rule] {{0, 1, 2, 3, 4}, {0, 1}, Automatic}, 
        Mesh -> False]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(tmp4 = 
      Plot3D[Tggfn[x, y], {x, 0, xmax}, {y, 0, ymax}, 
        PlotRange \[Rule] {\(-4\), 10}, ViewPoint \[Rule] view, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", \*"\"\<\!\(e\^D\)\>\""}, 
        BoxRatios \[Rule] {xmax, ymax, 1}, PlotPoints \[Rule] 40, 
        Ticks \[Rule] {{0, 1, 2, 3, 4}, {0, 1}, Automatic}, 
        Mesh -> False]\)}], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 969}},
WindowSize->{906, 938},
WindowMargins->{{87, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 77, 0, 30, "Subsubtitle"],
Cell[1856, 55, 89, 2, 33, "Text"],
Cell[1948, 59, 56, 1, 30, "Input"],
Cell[2007, 62, 102, 3, 33, "Text"],
Cell[2112, 67, 38, 1, 30, "Input"],
Cell[2153, 70, 45, 0, 33, "Text"],
Cell[2201, 72, 1490, 28, 550, "Input"],
Cell[3694, 102, 51, 0, 33, "Text"],
Cell[3748, 104, 593, 13, 270, "Input"],
Cell[4344, 119, 121, 3, 33, "Text"],
Cell[4468, 124, 395, 7, 212, "Input"],
Cell[4866, 133, 38, 0, 33, "Text"],
Cell[4907, 135, 4421, 74, 1422, "Input"],
Cell[9331, 211, 66, 0, 33, "Text"],
Cell[9400, 213, 1508, 31, 350, "Input"],
Cell[10911, 246, 80, 1, 30, "Input"],
Cell[10994, 249, 514, 10, 110, "Input"],
Cell[11511, 261, 1713, 34, 356, "Input"],
Cell[13227, 297, 1031, 22, 230, "Input"],
Cell[14261, 321, 281, 6, 71, "Text"],
Cell[14545, 329, 89, 1, 30, "Input"],
Cell[14637, 332, 439, 9, 105, "Input"],
Cell[15079, 343, 131, 3, 33, "Text"],
Cell[15213, 348, 1560, 28, 316, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

